# Copyright 1999-2022 Gentoo Authors
# Distributed under the terms of the GNU General Public License v2

# TODO:
# Add --enable-spotify when it works

EAPI=7

inherit autotools eutils user

DESCRIPTION="A DAAP (iTunes) media server"
HOMEPAGE="https://github.com/owntone/owntone-server"
#SRC_URI="https://github.com/owntone/owntone-server/archive/${PV}.tar.xz -> ${P}.tar.xz"
SRC_URI="https://github.com/owntone/owntone-server/releases/download/${PV}/${P}.tar.xz"
LICENSE="GPL-2"
SLOT="0"
KEYWORDS="~amd64"
IUSE="alsa flac itunes lastfm mpd musepack"

# Note: mpd support appears to be standalone, e.g. --enable-mpd doesn't
# result in additional linkage.
RDEPEND="
	dev-db/sqlite:3
	dev-libs/antlr-c:0
	dev-libs/confuse
	dev-libs/libevent
	dev-libs/libgcrypt:0
	dev-libs/libunistring
	dev-libs/libsodium
	net-libs/libwebsockets:0/15
	dev-libs/mxml[threads]
	net-dns/avahi[dbus]
	virtual/ffmpeg
	dev-libs/json-c

	alsa? ( media-libs/alsa-lib )
	flac? ( media-libs/flac )
	itunes? ( app-pda/libplist )
	lastfm? ( net-misc/curl )
	musepack? ( media-libs/taglib )
"

DEPEND="
	dev-java/antlr:3
	${RDEPEND}
"

pkg_setup() {
	enewuser daapd
	enewgroup daapd
}

src_prepare() {
	# https://github.com/ejurgensen/forked-daapd/pull/185
	#epatch "${FILESDIR}/antlr-3.5.patch"
	default
}

src_configure() {
	ac_cv_prog_ANTLR=antlr3.5 \
	econf \
		$(use_enable alsa) \
		$(use_enable flac) \
		$(use_enable musepack) \
		$(use_enable itunes) \
		$(use_enable lastfm) \
		$(use_enable mpd)
}

src_install() {
	emake DESTDIR="${D}" install

	newinitd "${FILESDIR}/daapd.initd" owntone
	newconfd "${FILESDIR}/daapd.confd" owntone

	# dodir by itself fails in the likely case of /srv/music having a
	# volume mounted already.
	test -d /srv/music || dodir /srv/music

	keepdir /var/lib/cache/owntone
	fowners -R daapd:daapd /var/lib/cache/owntone
}
